==> smooth-0.9.4.tar.gz: smooth-0.9.4/classes/i18n/locales/smooth_fa.h <==
 /* The smooth Class Library
  * Copyright (C) 1998-2014 Robert Kausch <robert.kausch@gmx.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of "The Artistic License, Version 2.0".
  *
  * THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE. */

#ifndef H_OBJSMOOTH_I18N_FA
#define H_OBJSMOOTH_I18N_FA

static const char *smooth_fa = 

	"<?xml version=\"1.0\" encoding=\"UTF-8\"?>					\
	 <LangFile>									\
	   <info>									\
	     <property name=\"program\">smooth</property>				\
	     <property name=\"language\">Farsi / فارسی</property>			\
	     <property name=\"righttoleft\">true</property>				\
	     <property name=\"encoding\">UTF-8</property>				\
	   </info>									\
	   <data>									\
	     <entry string=\"OK\">تأیید</entry>						\
	     <entry string=\"Cancel\">لغو</entry>					\
	     <entry string=\"Yes\">بله</entry>						\
	     <entry string=\"No\">نه</entry>						\
	     <entry string=\"Retry\">سعی مجدد</entry>					\
	     <entry string=\"Abort\">ساقط کردن</entry>					\
	     <entry string=\"Ignore\">چشم‌پوشی</entry>					\
											\
	     <entry string=\"Undo\">واگرد</entry>					\
	     <entry string=\"Cut\">برش</entry>						\
	     <entry string=\"Copy\">رونوشت</entry>					\
	     <entry string=\"Paste\">چسباندن</entry>					\
	     <entry string=\"Clear\">پاک کردن</entry>					\
	     <entry string=\"Select all\">برگزیدن همه</entry>				\
											\
	     <entry string=\"Backspace\">پس‌بر</entry>					\
	     <entry string=\"Tab\">جهش</entry>						\
	     <entry string=\"Return\">بازگشت</entry>					\
	     <entry string=\"Esc\">گریز</entry>						\
	     <entry string=\"Space\">فاصله</entry>					\
	     <entry string=\"PgUp\">بالابر صفحه</entry>					\
	     <entry string=\"PgDown\">پایین‌بر صفحه</entry>				\
	     <entry string=\"End\">پایان</entry>					\
	     <entry string=\"Home\">آغازه</entry>					\
	     <entry string=\"Left\">چپ</entry>						\
	     <entry string=\"Up\">بال</entry>						\
	     <entry string=\"Right\">راست</entry>					\
	     <entry string=\"Down\">پایین</entry>					\
	     <entry string=\"Ins\">درج</entry>						\
	     <entry string=\"Del\">حذف</entry>						\
	     <entry string=\"Ctrl\">مهار</entry>					\
	     <entry string=\"Alt\">دگرساز</entry>					\
	     <entry string=\"Shift\">تبدیل</entry>					\
											\
	     <entry string=\"Open file\">باز کردن پرونده</entry>			\
	     <entry string=\"Save file\">ذخیرۀ پرونده</entry>				\
	     <entry string=\"Save file as\">ذخیرۀ پرونده به عنوان</entry>		\
	     <entry string=\"Select directory\">برگزیدن پوشه</entry>			\
	     <entry string=\"Select font\">برگزیدن قلم</entry>				\
											\
	     <entry string=\"Color selection\">برگزیدن رنگ</entry>			\
	     <entry string=\"HTML code\">کد اچ</entry>					\
											\
	     <entry string=\"Tip of the day\">نکتۀ روز</entry>				\
	     <entry string=\"Did you know...\">آیا می‌دانید...</entry>			\
	     <entry string=\"Show tips on startup\">نمایش نکات هنگام راه‌اندازی</entry>	\
	     <entry string=\"Next tip\">بعدی</entry>					\
	   </data>									\
	 </LangFile>";

#endif

==> smooth_0.9.10.orig.tar.gz: smooth-0.9.10/classes/i18n/locales/smooth_fa.h <==
 /* The smooth Class Library
  * Copyright (C) 1998-2020 Robert Kausch <robert.kausch@gmx.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of "The Artistic License, Version 2.0".
  *
  * THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
  * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
  * WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE. */

#ifndef H_OBJSMOOTH_I18N_FA
#define H_OBJSMOOTH_I18N_FA

static const char *smooth_fa = 

	"<?xml version=\"1.0\" encoding=\"UTF-8\"?>					\
	 <LangFile>									\
	   <info>									\
	     <property name=\"program\">smooth</property>				\
	     <property name=\"language\">Farsi / فارسی</property>			\
	     <property name=\"righttoleft\">true</property>				\
	     <property name=\"encoding\">UTF-8</property>				\
	   </info>									\
	   <data>									\
	     <entry string=\"?\">؟</entry>						\
											\
	     <entry string=\"OK\">تأیید</entry>						\
	     <entry string=\"Cancel\">لغو</entry>					\
	     <entry string=\"Yes\">بله</entry>						\
	     <entry string=\"No\">نه</entry>						\
	     <entry string=\"Retry\">سعی مجدد</entry>					\
	     <entry string=\"Abort\">لغو</entry>					\
	     <entry string=\"Ignore\">چشم پوشي</entry>					\
											\
	     <entry string=\"Undo\">واگرد</entry>					\
	     <entry string=\"Cut\">برش</entry>						\
	     <entry string=\"Copy\">کپي</entry>						\
	     <entry string=\"Paste\">چسباندن</entry>					\
	     <entry string=\"Clear\">پاک کردن</entry>					\
	     <entry string=\"Select all\">برگزیدن همه</entry>				\
											\
	     <entry string=\"Open file\">باز کردن فايل</entry>				\
	     <entry string=\"Save file\">ذخیرۀ فايل</entry>				\
	     <entry string=\"Save file as\">ذخیرۀ فايل به عنوان</entry>			\
	     <entry string=\"Select directory\">برگزیدن پوشه</entry>			\
	     <entry string=\"Select font\">برگزیدن فونت</entry>				\
											\
	     <entry string=\"Color selection\">برگزیدن رنگ</entry>			\
	     <entry string=\"HTML code\">HTML کد</entry>				\
											\
	     <entry string=\"Tip of the day\">نکتۀ روز</entry>				\
	     <entry string=\"Did you know...\">آیا می‌دانید...</entry>			\
	     <entry string=\"Show tips on startup\">نمایش نکات هنگام راه‌اندازی</entry>	\
	     <entry string=\"Next tip\">بعدی</entry>					\
	   </data>									\
	 </LangFile>";

#endif
